@@ -130,7 +130,7 @@ class TestServersDescription(base.ClientTestBase):
         output = self.nova("update %s --description '%s'" % (server.id, descr),
                            fail_ok=True, merge_stderr=True)
         self.assertIn("ERROR (BadRequest): Invalid input for field/attribute"
-                      " description. Value: %s. u\'%s\' is too long (HTTP 400)"
+                      " description. Value: %s. '%s' is too long (HTTP 400)"
                       % (descr, descr), output)
 
 
@@ -288,7 +288,7 @@ class TestServersDetailsFlavorInfo(base.ClientTestBase):
                 flavor_details, key)
             server_flavor_val = self._get_value_from_the_table(
                 server_details, flavor_key_mapping[key])
-            if key is "swap" and flavor_val is "":
+            if key == "swap" and flavor_val == "":
                 # "flavor-show" displays zero swap as empty string.
                 flavor_val = '0'
             self.assertEqual(flavor_val, server_flavor_val)
