@@ -271,28 +271,6 @@ class Base(base.Fixture):
                                status_code=204,
                                headers=self.json_headers)
 
-        def post_os_volumes_boot(request, context):
-            body = request.json()
-            assert (set(body.keys()) <=
-                    set(['server', 'os:scheduler_hints']))
-
-            fakes.assert_has_keys(body['server'],
-                                  required=['name', 'flavorRef'],
-                                  optional=['imageRef'])
-
-            data = body['server']
-
-            # Require one, and only one, of the keys for bdm
-            if 'block_device_mapping' not in data:
-                if 'block_device_mapping_v2' not in data:
-                    msg = "missing required keys: 'block_device_mapping'"
-                    raise AssertionError(msg)
-            elif 'block_device_mapping_v2' in data:
-                msg = "found extra keys: 'block_device_mapping'"
-                raise AssertionError(msg)
-
-            return {'server': self.server_9012}
-
         #
         # Server password
         #
@@ -371,6 +349,10 @@ class V1(Base):
         self.requests_mock.delete(self.url('1234', 'os-interface', 'port-id'),
                                   headers=self.json_headers)
 
+        self.requests_mock.get(self.url('1234', 'topology'),
+                               json=v2_fakes.SERVER_TOPOLOGY,
+                               headers=self.json_headers)
+
         # Testing with the following password and key
         #
         # Clear password: FooBar123
@@ -456,6 +438,19 @@ class V1(Base):
             return None
         elif action == 'lock':
             return None
+        elif action == 'unshelve':
+            if api_version >= api_versions.APIVersion("2.91"):
+                # In 2.91 and above, we allow body to be one of these:
+                # {'unshelve': None}
+                # {'unshelve': {'availability_zone': <string>}}
+                # {'unshelve': {'availability_zone': None}}   (Unpin az)
+                # {'unshelve': {'host': <fqdn>}}
+                # {'unshelve': {'availability_zone': <string>, 'host': <fqdn>}}
+                # {'unshelve': {'availability_zone': None, 'host': <fqdn>}}
+                if body[action] is not None:
+                    for key in body[action].keys():
+                        key in ['availability_zone', 'host']
+            return None
         elif action == 'rebuild':
             body = body[action]
             adminPass = body.get('adminPass', 'randompassword')
